@@ -13,7 +13,7 @@ class OpenViduSubscriber(object):
 
     def __init__(self, session: BaseUrlSession, session_id: str, data: dict):
         """
-        This is meant for internal use, thus you should not call it.
+        Direct instantiation of this class is not supported!
         Use `OpenViduConnection.subscribers` to get an instance of this class.
         """
 
